@@ -43,7 +43,6 @@ describe 'neutron::agents::ml2::ovs' do
       is_expected.to contain_neutron_agent_ovs('agent/polling_interval').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_agent_ovs('agent/l2_population').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_agent_ovs('agent/arp_responder').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_agent_ovs('agent/prevent_arp_spoofing').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_agent_ovs('agent/drop_flows_on_start').with_value(p[:drop_flows_on_start])
       is_expected.to contain_neutron_agent_ovs('agent/extensions').with_value(['<SERVICE DEFAULT>'])
       is_expected.to contain_neutron_agent_ovs('agent/minimize_polling').with_value(['<SERVICE DEFAULT>'])
@@ -109,15 +108,6 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'when disabling ARP Spoofing Protection' do
-      before :each do
-        params.merge!(:prevent_arp_spoofing => false)
-      end
-      it 'should disable ARP Spoofing Protection' do
-        is_expected.to contain_neutron_agent_ovs('agent/prevent_arp_spoofing').with_value(false)
-      end
-    end
-
     context 'when enabling DVR' do
       before :each do
         params.merge!(:enable_distributed_routing => true,
