@@ -13,7 +13,7 @@ describe 'neutron::plugins::ml2::bigswitch::restproxy' do
      class { 'neutron::server': }
      class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :required_params do
