@@ -25,7 +25,7 @@ describe 'neutron::plugins::ml2' do
   let :pre_condition do
     "class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :default_params do
@@ -61,7 +61,7 @@ describe 'neutron::plugins::ml2' do
     it { is_expected.to contain_class('neutron::params') }
 
     it 'configures neutron.conf' do
-        is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value('neutron.plugins.ml2.plugin.Ml2Plugin')
+        is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value('ml2')
     end
 
     it 'passes purge to resource' do
@@ -77,6 +77,7 @@ describe 'neutron::plugins::ml2' do
       is_expected.to contain_neutron_plugin_ml2('ml2/extension_drivers').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_plugin_ml2('ml2/path_mtu').with_value(p[:path_mtu])
       is_expected.to contain_neutron_plugin_ml2('ml2/physical_network_mtus').with_ensure('absent')
+      is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_plugin_ml2('securitygroup/firewall_driver').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_plugin_ml2('securitygroup/enable_security_group').with_value('<SERVICE DEFAULT>')
     end
@@ -105,12 +106,39 @@ describe 'neutron::plugins::ml2' do
       before :each do
         params.merge!(
           :enable_security_group => true,
-          :firewall_driver       => 'neutron.agent.linux.iptables_firewall.OVSHybridIptablesFirewallDriver',
+          :firewall_driver       => 'iptables_hybrid',
         )
       end
       it 'configures enable_security_group and firewall_driver options' do
         is_expected.to contain_neutron_plugin_ml2('securitygroup/enable_security_group').with_value('true')
-        is_expected.to contain_neutron_plugin_ml2('securitygroup/firewall_driver').with_value('neutron.agent.linux.iptables_firewall.OVSHybridIptablesFirewallDriver')
+        is_expected.to contain_neutron_plugin_ml2('securitygroup/firewall_driver').with_value('iptables_hybrid')
+      end
+    end
+
+    context 'when specifying IPv4 overlays' do
+      before :each do
+        params.merge!(:overlay_ip_version => 4)
+      end
+      it 'configures as IPv4' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value(4)
+      end
+    end
+
+    context 'when specifying IPv6 overlays' do
+      before :each do
+        params.merge!(:overlay_ip_version => 6)
+      end
+      it 'configures as IPv6' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value(6)
+      end
+    end
+
+    context 'when specifying an invalid overlay IP versions' do
+      before :each do
+        params.merge!(:overlay_ip_version => 10)
+      end
+      it 'fails to accept value' do
+        is_expected.to raise_error(Puppet::Error)
       end
     end
 
